// WStar Drawing program

//  PROPIX, Written by Pintr Gbor
// Szkesfehrvr, Krivnyi u. 15.
// H-8000, HUNGARY
// Tel: +36 30 9972445
// Fax: +36 22 304326
// Email: propix@mail.datatrans.hu
//        Pinter.Gabor@freemail.hu
// Web: www.propix.hu
//      www.datatrans.hu/propix

// Revisions:
//  V1.0  01/19/1997  First version written in C
//  V3.0  02/19/1998  Rewritten in Delphi 3
//  V5.0  08/25/2000  Recompiled with Delphi 5
//  V5.01 11/14/2000  More features, source reorganized
//  V5.02 11/30/2000  Transparent background added
//  V5.03 12/13/2000  PinyoDrawing is a component

unit BackgroundUnit;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs, StdCtrls, ExtCtrls,
  DrawUnit;

type
  TBackgroundForm = class(TForm)
    BackColor: TColorDialog;
    ColorButton: TButton;
    StyleGroup: TGroupBox;
    SolidRB: TRadioButton;
    CrossRB: TRadioButton;
    XCrossRB: TRadioButton;
    HorizontalRB: TRadioButton;
    VerticalRB: TRadioButton;
    FDiagonalRB: TRadioButton;
    BDiagonalRB: TRadioButton;
    OKButton: TButton;
    CancelButton: TButton;
    TransparentRB: TRadioButton;
    Sample: TPinyoDrawing;
    procedure ColorButtonClick(Sender: TObject);
    procedure StyleClick(Sender: TObject);
    procedure FormShow(Sender: TObject);
    procedure OKButtonClick(Sender: TObject);
  end;

var
  BackgroundForm: TBackgroundForm;

implementation

uses MainUnit;

{$R *.DFM}


//----------------------------------------------------------------------------------------------------------------------
// Initialize controls and interpret selection


// Initialize controls
procedure TBackgroundForm.FormShow(Sender: TObject);
begin
  case MainForm.PinyoDrawing.BrushStyle of                                      // Current style
    bsSolid:      SolidRB.Checked:= True;
    bsCross:      CrossRB.Checked:= True;
    bsDiagCross:  XCrossRB.Checked:= True;
    bsHorizontal: HorizontalRB.Checked:= True;
    bsVertical:   VerticalRB.Checked:= True;
    bsFDiagonal:  FDiagonalRB.Checked:= True;
    bsBDiagonal:  BDiagonalRB.Checked:= True;
    bsClear:      TransparentRB.Checked:= True;
  end;
  BackColor.Color:= MainForm.PinyoDrawing.BackColor;                            // Current color
  Sample.BackColor:= MainForm.PinyoDrawing.BackColor;                           // Current parameters to Sample
  Sample.ForeColor:= MainForm.PinyoDrawing.ForeColor;
  if MainForm.PinyoDrawing.BrushStyle=bsClear then
  begin
    Sample.BrushStyle:= bsSolid;                                                // Sample cannot be transparent
  end
  else
  begin
    Sample.BrushStyle:= MainForm.PinyoDrawing.BrushStyle;
  end;
  Sample.PenMode:= MainForm.PinyoDrawing.PenMode;
  Sample.PenStyle:= MainForm.PinyoDrawing.PenStyle;
  Sample.PenWidth:= MainForm.PinyoDrawing.PenWidth;
  Sample.Picture:= MainForm.PinyoDrawing.Picture;
  case MainForm.PinyoDrawing.Picture of                                         // Smaller and faster
    pcNephroid:
      begin
        Sample.Points:= 20;
      end;
    pcPascal:
      begin
        Sample.Points:= 30;
      end;
    else // pcStar:
      begin
        Sample.Points:= 9;
      end;
  end;
end;


// OK button click
procedure TBackgroundForm.OKButtonClick(Sender: TObject);
begin
  MainForm.PinyoDrawing.BackColor:= BackgroundForm.BackColor.Color;             // New color
  if SolidRB.Checked      then                                                  // New style
    MainForm.PinyoDrawing.BrushStyle:= bsSolid      else
  if CrossRB.Checked      then
    MainForm.PinyoDrawing.BrushStyle:= bsCross      else
  if XCrossRB.Checked     then
    MainForm.PinyoDrawing.BrushStyle:= bsDiagCross  else
  if HorizontalRB.Checked then
    MainForm.PinyoDrawing.BrushStyle:= bsHorizontal else
  if VerticalRB.Checked   then
    MainForm.PinyoDrawing.BrushStyle:= bsVertical   else
  if FDiagonalRB.Checked  then
    MainForm.PinyoDrawing.BrushStyle:= bsFDiagonal  else
  if BDiagonalRB.Checked  then
    MainForm.PinyoDrawing.BrushStyle:= bsBDiagonal  else
  if TransparentRB.Checked  then
    MainForm.PinyoDrawing.BrushStyle:= bsClear;
end;



//----------------------------------------------------------------------------------------------------------------------
// Controls


// Select color and repaint sample box
procedure TBackgroundForm.ColorButtonClick(Sender: TObject);
begin
  if BackColor.Execute then                                                     // Select color
  begin
    Sample.BackColor:= BackColor.Color;                                         // Repaint sample box
  end;
end;


// Style changed -> repaint sample box
procedure TBackgroundForm.StyleClick(Sender: TObject);
begin
  if SolidRB.Checked       then Sample.BrushStyle:= bsSolid else                // New style
  if CrossRB.Checked       then Sample.BrushStyle:= bsCross else
  if XCrossRB.Checked      then Sample.BrushStyle:= bsDiagCross else
  if HorizontalRB.Checked  then Sample.BrushStyle:= bsHorizontal else
  if VerticalRB.Checked    then Sample.BrushStyle:= bsVertical else
  if FDiagonalRB.Checked   then Sample.BrushStyle:= bsFDiagonal else
  if BDiagonalRB.Checked   then Sample.BrushStyle:= bsBDiagonal else
  if TransparentRB.Checked then Sample.BrushStyle:= bsSolid;                    // Sample cannot be transparent
end;


end.
